CachePolicyEntry class
ContextEntry wrapper for CachePolicy.
Constructors
- CachePolicyEntry(CachePolicy policy)
-
const
Properties
-
fieldsForEquality
→ List<
Object?> -
List of values to be used for equality.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- policy → CachePolicy
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object o) → bool -
The equality operator.
inherited