compact method

Future<void> compact()

Compacts the underlying Hive box to reclaim disk space.

This is useful after deleting many entries to reduce the file size.

Example:

await store.compact();

Implementation

Future<void> compact() async {
  await _storageBox.compact();
}