clearCache method
Clears all cached data.
Use this sparingly as it removes all cache entries.
Example:
// On user logout
await client.clearCache();
Implementation
Future<void> clearCache() async => _cacheLink.clear();
Clears all cached data.
Use this sparingly as it removes all cache entries.
Example:
// On user logout
await client.clearCache();
Future<void> clearCache() async => _cacheLink.clear();