isExpired property
bool
get
isExpired
Checks if this cache entry has expired based on its TTL.
Returns false if no TTL is set (never expires).
Returns true if the current time exceeds timestamp + TTL.
Implementation
bool get isExpired {
if (ttl == null) return false;
return DateTime.now().difference(timestamp) > ttl!;
}